( cd usr/lib ; rm -rf libgeotiff.so.1.2 )
( cd usr/lib ; ln -sf libgeotiff.so.1.2.2 libgeotiff.so.1.2 )
( cd usr/lib ; rm -rf libgeotiff.so.1 )
( cd usr/lib ; ln -sf libgeotiff.so.1.2 libgeotiff.so.1 )
( cd usr/lib ; rm -rf libgeotiff.so )
( cd usr/lib ; ln -sf libgeotiff.so.1 libgeotiff.so )
